Index: kernel/generic/include/proc/thread.h
===================================================================
--- kernel/generic/include/proc/thread.h	(revision ea7890e7d40b57d264d11b6a6ded9dd8c6454424)
+++ kernel/generic/include/proc/thread.h	(revision c03ee1c304c982b593d8043411e6b003dd1c155a)
@@ -82,6 +82,6 @@
 	/** After a thread calls thread_exit(), it is put into Exiting state. */
 	Exiting,
-	/** Threads that were not detached but exited are in the JoinMe state. */
-	JoinMe
+	/** Threads that were not detached but exited are Lingering. */
+	Lingering
 } state_t;
 
